# extraneous

Find extraneous pip packages not listed in your requirements.txt or as a sub-dependency.

![extraneous logo](https://docs.arrai-dev.com/extraneous/readme/extraneous.png)

###### master

![Tests](https://docs.arrai-dev.com/extraneous/master.python38.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/master.python38.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_master_python38/)

![Tests](https://docs.arrai-dev.com/extraneous/master.python37.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/master.python37.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_master_python37/)

![Tests](https://docs.arrai-dev.com/extraneous/master.python36.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/master.python36.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_master_python36/)

![Flake8](https://docs.arrai-dev.com/extraneous/master.flake8.svg)

###### develop

![Tests](https://docs.arrai-dev.com/extraneous/develop.python38.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/develop.python38.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_develop_python38/)

![Tests](https://docs.arrai-dev.com/extraneous/develop.python37.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/develop.python37.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_develop_python37/)

![Tests](https://docs.arrai-dev.com/extraneous/develop.python36.svg) [![Coverage](https://docs.arrai-dev.com/extraneous/develop.python36.coverage.svg)](https://docs.arrai-dev.com/extraneous/htmlcov_develop_python36/)

![Flake8](https://docs.arrai-dev.com/extraneous/develop.flake8.svg)
